# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import permission_pb2 as permission__pb2


class PermissionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.permission.PermissionApi/create',
                request_serializer=permission__pb2.PermissionCreateRequest.SerializeToString,
                response_deserializer=permission__pb2.PermissionCreateResponse.FromString,
                )
        self.delete = channel.unary_unary(
                '/oi.papi.permission.PermissionApi/delete',
                request_serializer=permission__pb2.PermissionDeleteRequest.SerializeToString,
                response_deserializer=permission__pb2.PermissionDeleteResponse.FromString,
                )


class PermissionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Adds Permissions for the specified users to the specified resources.
        Works for all resource types, but does not add permissions for any dependent or child resources.
        Subject ID could be a User, a UserCollection or the root subject.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Removes Permissions for the specified users from the specified resources.
        Works for all resource types., but does not remove Permissions for any dependent or child resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PermissionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=permission__pb2.PermissionCreateRequest.FromString,
                    response_serializer=permission__pb2.PermissionCreateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=permission__pb2.PermissionDeleteRequest.FromString,
                    response_serializer=permission__pb2.PermissionDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.permission.PermissionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PermissionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.permission.PermissionApi/create',
            permission__pb2.PermissionCreateRequest.SerializeToString,
            permission__pb2.PermissionCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.permission.PermissionApi/delete',
            permission__pb2.PermissionDeleteRequest.SerializeToString,
            permission__pb2.PermissionDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import token_pb2 as token__pb2


class TokenApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.TokenApi/create',
                request_serializer=token__pb2.TokenCreateRequest.SerializeToString,
                response_deserializer=token__pb2.TokenCreateResponse.FromString,
                )


class TokenApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        As an authenticated user, generate a new API token, often one that lives longer to continue to use the system.
        By default, new tokens last for an hour. The maximum duration of a token is currently 1 year.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=token__pb2.TokenCreateRequest.FromString,
                    response_serializer=token__pb2.TokenCreateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.TokenApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TokenApi/create',
            token__pb2.TokenCreateRequest.SerializeToString,
            token__pb2.TokenCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: visualization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13visualization.proto\x12\x15oi.papi.visualization\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x05\n\rVisualization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x63omputation_id\x18\x02 \x01(\t\x12\x1d\n\x15result_observation_id\x18\x03 \x01(\t\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).oi.papi.visualization.Visualization.Type\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32*.oi.papi.visualization.Visualization.State\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14observation_metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x0b\x61\x63\x63\x65ss_info\x18\x07 \x01(\x0b\x32/.oi.papi.visualization.Visualization.AccessInfo\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aP\n\nAccessInfo\x12\x14\n\x0curl_template\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x0b\n\x07SPATIAL\x10\x02\x12\x0c\n\x08TEMPORAL\x10\x03\"\x7f\n\x05State\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\n\n\x06QUEUED\x10\x02\x12\x0e\n\nVALIDATING\x10\x03\x12\t\n\x05\x45MPTY\x10\x04\x12\x0c\n\x08UPLOADED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\x0b\n\x07\x44\x45LETED\x10\x08\"9\n\x17VisualizationGetRequest\x12\x1e\n\x16result_observation_ids\x18\x01 \x03(\t\"\x88\x01\n\x18VisualizationGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12<\n\x0evisualizations\x18\x02 \x03(\x0b\x32$.oi.papi.visualization.Visualization\x12\x19\n\x11\x62\x61se_url_template\x18\x03 \x01(\t\"\xdd\x01\n\nVisualizer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12I\n\x0fvisualizer_type\x18\x03 \x01(\x0e\x32\x30.oi.papi.visualization.Visualizer.VisualizerType\x12\x11\n\tdata_type\x18\x04 \x01(\t\"W\n\x0eVisualizerType\x12\x1b\n\x17UNKNOWN_VISUALIZER_TYPE\x10\x00\x12\n\n\x06KEPLER\x10\x01\x12\x1c\n\x18OI_VISUALIZATION_SERVICE\x10\x02\"~\n\x10VisualizerConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\nvisualizer\x18\x03 \x01(\x0b\x32!.oi.papi.visualization.Visualizer\"y\n\x14VisualizerConfigAlgo\x12\x1c\n\x14\x61lgorithm_version_id\x18\x01 \x01(\t\x12\x43\n\x12visualizer_configs\x18\x02 \x03(\x0b\x32\'.oi.papi.visualization.VisualizerConfig\"_\n!VisualizerConfigAlgoCreateRequest\x12\x1c\n\x14visualizer_config_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61lgorithm_version_id\x18\x02 \x01(\t\"9\n\"VisualizerConfigAlgoCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"?\n\x1eVisualizerConfigAlgoGetRequest\x12\x1d\n\x15\x61lgorithm_version_ids\x18\x01 \x03(\t\"\x84\x01\n\x1fVisualizerConfigAlgoGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12L\n\x17visualizer_config_algos\x18\x02 \x03(\x0b\x32+.oi.papi.visualization.VisualizerConfigAlgo2\x89\x03\n\x10VisualizationApi\x12\x66\n\x03get\x12..oi.papi.visualization.VisualizationGetRequest\x1a/.oi.papi.visualization.VisualizationGetResponse\x12\x89\x01\n\x12\x63reate_config_algo\x12\x38.oi.papi.visualization.VisualizerConfigAlgoCreateRequest\x1a\x39.oi.papi.visualization.VisualizerConfigAlgoCreateResponse\x12\x80\x01\n\x0fget_config_algo\x12\x35.oi.papi.visualization.VisualizerConfigAlgoGetRequest\x1a\x36.oi.papi.visualization.VisualizerConfigAlgoGetResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'visualization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISUALIZATION._serialized_start=110
  _VISUALIZATION._serialized_end=850
  _VISUALIZATION_ACCESSINFO._serialized_start=574
  _VISUALIZATION_ACCESSINFO._serialized_end=654
  _VISUALIZATION_TYPE._serialized_start=656
  _VISUALIZATION_TYPE._serialized_end=721
  _VISUALIZATION_STATE._serialized_start=723
  _VISUALIZATION_STATE._serialized_end=850
  _VISUALIZATIONGETREQUEST._serialized_start=852
  _VISUALIZATIONGETREQUEST._serialized_end=909
  _VISUALIZATIONGETRESPONSE._serialized_start=912
  _VISUALIZATIONGETRESPONSE._serialized_end=1048
  _VISUALIZER._serialized_start=1051
  _VISUALIZER._serialized_end=1272
  _VISUALIZER_VISUALIZERTYPE._serialized_start=1185
  _VISUALIZER_VISUALIZERTYPE._serialized_end=1272
  _VISUALIZERCONFIG._serialized_start=1274
  _VISUALIZERCONFIG._serialized_end=1400
  _VISUALIZERCONFIGALGO._serialized_start=1402
  _VISUALIZERCONFIGALGO._serialized_end=1523
  _VISUALIZERCONFIGALGOCREATEREQUEST._serialized_start=1525
  _VISUALIZERCONFIGALGOCREATEREQUEST._serialized_end=1620
  _VISUALIZERCONFIGALGOCREATERESPONSE._serialized_start=1622
  _VISUALIZERCONFIGALGOCREATERESPONSE._serialized_end=1679
  _VISUALIZERCONFIGALGOGETREQUEST._serialized_start=1681
  _VISUALIZERCONFIGALGOGETREQUEST._serialized_end=1744
  _VISUALIZERCONFIGALGOGETRESPONSE._serialized_start=1747
  _VISUALIZERCONFIGALGOGETRESPONSE._serialized_end=1879
  _VISUALIZATIONAPI._serialized_start=1882
  _VISUALIZATIONAPI._serialized_end=2275
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import aoi_export_pb2 as aoi__export__pb2


class AOIExportApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.export_aois = channel.unary_unary(
                '/oi.papi.AOIExportApi/export_aois',
                request_serializer=aoi__export__pb2.AOIExportRequest.SerializeToString,
                response_deserializer=aoi__export__pb2.AOIExportResponse.FromString,
                )
        self.export_collection = channel.unary_unary(
                '/oi.papi.AOIExportApi/export_collection',
                request_serializer=aoi__export__pb2.AOICollectionExportRequest.SerializeToString,
                response_deserializer=aoi__export__pb2.AOICollectionExportResponse.FromString,
                )


class AOIExportApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def export_aois(self, request, context):
        """
        Exports supplied aoi_ids to a file format specified.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def export_collection(self, request, context):
        """
        Exports supplied aoi_collection into the file format specified
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOIExportApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'export_aois': grpc.unary_unary_rpc_method_handler(
                    servicer.export_aois,
                    request_deserializer=aoi__export__pb2.AOIExportRequest.FromString,
                    response_serializer=aoi__export__pb2.AOIExportResponse.SerializeToString,
            ),
            'export_collection': grpc.unary_unary_rpc_method_handler(
                    servicer.export_collection,
                    request_deserializer=aoi__export__pb2.AOICollectionExportRequest.FromString,
                    response_serializer=aoi__export__pb2.AOICollectionExportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOIExportApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AOIExportApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def export_aois(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOIExportApi/export_aois',
            aoi__export__pb2.AOIExportRequest.SerializeToString,
            aoi__export__pb2.AOIExportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def export_collection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.AOIExportApi/export_collection',
            aoi__export__pb2.AOICollectionExportRequest.SerializeToString,
            aoi__export__pb2.AOICollectionExportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\xc3\x01\n\x19SubscriptionCreateRequest\x12\x46\n\rsubscriptions\x18\x01 \x03(\x0b\x32/.oi.papi.SubscriptionCreateRequest.Subscription\x1a^\n\x0cSubscription\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12(\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t2q\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponseP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBSCRIPTIONCREATEREQUEST._serialized_start=83
  _SUBSCRIPTIONCREATEREQUEST._serialized_end=278
  _SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION._serialized_start=184
  _SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION._serialized_end=278
  _SUBSCRIPTIONCREATERESPONSE._serialized_start=280
  _SUBSCRIPTIONCREATERESPONSE._serialized_end=355
  _NOTIFICATIONAPI._serialized_start=357
  _NOTIFICATIONAPI._serialized_end=470
# @@protoc_insertion_point(module_scope)
